@@ -8,31 +8,29 @@
 # #############################################################################
 
 from htag import Tag
-import os
+import os,base64
 
-# TODO: doesn't work well with browserhttp runner ;-(
 
 class FileUpload(Tag.input):
-    """ TRANSFERT as BINARY STRING """
     statics=[Tag.H.script(r"""
 function fileupload( self, cbInteract ) {
     let file = self.files[0];
     var reader = new FileReader();
-    reader.onload =  e => { cbInteract(file.name, e.target.result) };
+    reader.onload =  e => { cbInteract(file.name, btoa(e.target.result)) };
     reader.readAsBinaryString(file); //reader.readAsText(file);
 }""")]
 
     def __init__(self,onchange,**a):
         Tag.__init__(self,**a)
         self["type"]="file"
-        self["onchange"]="fileupload(this, function(name,content) {%s})" % self.bind._onchange( b"name",b"content")
+        self["onchange"]="fileupload(this, function(name,content) {%s})" % self.bind._onchange( b"name", b"content")
         self.onchange=onchange
 
-    def _onchange(self,name,content):
-        self.onchange(name,content)
+    def _onchange(self,name:str,content:str):
+        self.onchange(name,base64.b64decode(content))
 
 if __name__=="__main__":
-    def showFile(name,content):
+    def showFile(name: str,content: bytes):
         print(name,content)
 
     obj=FileUpload( showFile )
